@@ -12,6 +12,7 @@ from operator import add
 import elasticsearch
 import elasticsearch_dsl
 from elasticsearch_dsl.connections import Connections
+from dateutil.parser import parse as dtparse
 
 from biothings.utils.web.es import get_es_versions
 from biothings.utils.web.es_transport import (BiothingsAsyncTransport,
@@ -49,6 +50,7 @@ class DataConnections:
             connection_settings.update(sniffer_timeout=60)
             connection_settings.update(sniff_on_start=True)
             connection_settings.update(sniff_on_connection_fail=True)
+            connection_settings.update(retry_on_timeout=True)
         self._connections.create_connection(alias='async', **connection_settings)
 
     async def log_versions(self):
@@ -387,7 +389,8 @@ class BiothingHubMeta(BiothingMetaProp):
 
         self.biothing_type = metadata.get('biothing_type')
         # self.build_date = datetime.fromisoformat(metadata['build_date']) # python3.7 syntax
-        self.build_date = datetime.strptime(metadata['build_date'], "%Y-%m-%dT%H:%M:%S.%f")
+        # self.build_date = datetime.strptime(metadata['build_date'], "%Y-%m-%dT%H:%M:%S.%f")
+        self.build_date = dtparse(metadata['build_date']).astimezone()    # this handles with timestamp string w/wo timezone
         self.build_version = metadata.get('build_version')
         self.src = metadata.get('src', {})
         self.stats = metadata.get('stats', {})
